/*                                                                              
 * PDFedit - free program for PDF document manipulation.                        
 * Copyright (C) 2006, 2007  PDFedit team:      Michal Hocko, 
 *                                              Miroslav Jahoda,       
 *                                              Jozef Misutka, 
 *                                              Martin Petricek                                             
 *
 * Project is hosted on http://sourceforge.net/projects/pdfedit                                                                      
 */ 
#ifndef __MAIN_H__
#define __MAIN_H__

class QApplication;

/** Main QApplication object */
extern QApplication *q_App;
/** Path to directory in which the binary resides */
extern QString appPath;

#endif
